from .options import MySettings, set_plot_colours
from .file import load_data, save_data, save_fig, export_to_matlab_jwlogger, export_to_matlab, export_to_csv
from .oscilloscope import Oscilloscope
from .acquisition import log_data, log_data_with_output, output_signal, signal_generator, stream_snapshot
from .datastructure import DataSet, TimeData, FreqData, CrossSpecData, TfData, SonoData, MetaData, ModalData, update_dataset
from .testdata import create_test_impulse_data, create_test_impulse_ensemble, create_test_noise_data
from .plotting import PlotData#, PlotTimeData, PlotData2
from .analysis import calculate_fft, calculate_cross_spectrum_matrix, calculate_cross_spectra_averaged, clean_impulse
from .analysis import calculate_tf, calculate_tf_averaged, multiply_by_power_of_iw, best_match, calculate_sonogram
from .streams import Recorder, Recorder_NI, start_stream, REC, setup_output_NI, setup_output_soundcard, list_available_devices, get_devices_NI, get_devices_soundcard
#from .interactive_tools import InteractiveLogging, InteractiveView
from .modal import modal_fit_single_channel, modal_fit_all_channels

from .gui import Logger